# nlp-qa-tfidf

#### 介绍
tfidf
余弦短文本求相似度

#### package
gensim
jieba
pandas


#### 安装教程

1.  pip install -i https://mirrors.aliyun.com/pypi/simple/ -r requirements.txt 

#### 使用说明

1.  运行qa文件
2.  questionList 可替换
